mediaMarker constant

String const mediaMarker

mtmd's default media marker. One is emitted into the prompt text per attached image; mtmd (LlamaSession evalMultimodalPrompt) splits the prompt on these and substitutes the model-specific image tokens. Matches mtmd_default_marker() ("<media>") in the vendored mtmd.h.

Implementation

static const String mediaMarker = '<__media__>';