dispose method
Performs application-defined tasks associated with freeing, releasing, or resetting unmanaged resources.
Implementation
@override
void dispose() {
// The session is owned by the hosted service that loaded it, not here.
}
Performs application-defined tasks associated with freeing, releasing, or resetting unmanaged resources.
@override
void dispose() {
// The session is owned by the hosted service that loaded it, not here.
}