latest property
PromptSnapshot?
get
latest
The most recent prompt sent to the model, or null if none yet.
Implementation
PromptSnapshot? get latest => _latest;
The most recent prompt sent to the model, or null if none yet.
PromptSnapshot? get latest => _latest;