onStop property
void Function()?
onStop
final
Invoked when a stop sequence match ends the stream.
Implementation
final void Function()? onStop;
Invoked when a stop sequence match ends the stream.
final void Function()? onStop;