values property

Map<String, String> values
final

Requested keys that were present with a string value. Keys that are absent, or whose value is not a string, are omitted.

Implementation

final Map<String, String> values;