contextTokens property

int contextTokens
final

The n_ctx the session had when the snapshot was taken. A snapshot can only be restored into a context at least tokens large.

Implementation

final int contextTokens;