memoryEstimate property
ModelMemoryEstimate?
get
memoryEstimate
The memory estimate for the loaded model, when one could be read.
Implementation
ModelMemoryEstimate? get memoryEstimate => _estimate;
The memory estimate for the loaded model, when one could be read.
ModelMemoryEstimate? get memoryEstimate => _estimate;