MemoryCriticalEvent class final

Even the minimum acceptable context no longer fits in memory.

Inheritance

Constructors

MemoryCriticalEvent({required MemorySnapshot snapshot, required int requiredBytes})
Creates the event.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
requiredBytes int
Bytes the minimum context would need.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
snapshot MemorySnapshot
The memory measurement that triggered the verdict.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited