resizeHysteresisFraction property
Target/current differences within this fraction are ignored — resizing recreates the context, so thrash costs more than being slightly off-budget.
Implementation
final double resizeHysteresisFraction;
Target/current differences within this fraction are ignored — resizing recreates the context, so thrash costs more than being slightly off-budget.
final double resizeHysteresisFraction;