unloadOnCritical property
Whether a memory-critical verdict unloads the model (instead of only emitting an event and hoping the app reacts).
Implementation
final bool unloadOnCritical;
Whether a memory-critical verdict unloads the model (instead of only emitting an event and hoping the app reacts).
final bool unloadOnCritical;