weightsBytes property
Weight cost — the GGUF file size(s). The file is mmapped, but with full GPU offload on unified memory it is effectively resident.
Implementation
final int weightsBytes;
Weight cost — the GGUF file size(s). The file is mmapped, but with full GPU offload on unified memory it is effectively resident.
final int weightsBytes;