ResizeContext class final

Recreate the context at toTokens.

Inheritance

Constructors

ResizeContext({required int fromTokens, required int toTokens, required ResizeReason reason})
Creates the decision.
const

Properties

fromTokens → int
The context size being replaced.
final
hashCode → int
The hash code for this object.
no setterinherited
reason → ResizeReason
Why the resize is proposed.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toTokens → int
The proposed context size.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited