SnapshotSavedEvent class final

An agent's KV state was snapshotted before switching away.

Inheritance

Constructors

SnapshotSavedEvent({required String agentId, required int tokens})
Creates the event.
const

Properties

agentId → String
The agent whose state was saved.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tokens → int
Tokens the snapshot covers.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited