bytes property
Stash size in bytes (held in process memory until restored, evicted, or the model is reloaded).
Implementation
final int bytes;
Stash size in bytes (held in process memory until restored, evicted, or the model is reloaded).
final int bytes;