Lfm2Prompt class
A rendered LFM prompt plus the stop sequences generation should halt on.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
images
→ List<
Uint8List> -
Image bytes referenced by the media markers embedded in text, in the
order the markers appear. Empty for a text-only prompt.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stopSequences
→ List<
String> -
Strings that terminate a generation turn. See
Lfm2ChatTemplate.stopSequences.
final
- text → String
-
The formatted prompt, ready to pass to
LlamaCppFlutter.generate.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited