smoothing property
Time constant of the rate filter: how quickly the release rate follows a change in generation speed. Larger values are steadier but slower to react to the model speeding up or slowing down.
Implementation
final Duration smoothing;
Time constant of the rate filter: how quickly the release rate follows a change in generation speed. Larger values are steadier but slower to react to the model speeding up or slowing down.
final Duration smoothing;