GgufMetadata class final
The metadata values found for the requested keys.
- Inheritance
-
- Object
- GgufMetadataResult
- GgufMetadata
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
numericValues
→ Map<
String, int> -
Requested keys that were present with an integer value (any GGUF
int width). Keys that are absent, or whose value is neither a string
nor an integer, are omitted from both maps.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
values
→ Map<
String, String> -
Requested keys that were present with a string value. Keys that are
absent, or whose value is not a string, are omitted.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited