AgentSnapshot class
Metadata about one agent's saved KV-cache snapshot.
Constructors
- AgentSnapshot({required String agentId, required String statePath, required int tokens, required int contextTokens})
-
Creates a snapshot record.
const
Properties
- agentId → String
-
The agent the snapshot belongs to.
final
- contextTokens → int
-
The
n_ctxthe session had when the snapshot was taken. A snapshot can only be restored into a context at least tokens large.final - hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statePath → String
-
Path of the state file written by
LlamaSession.saveState.final - tokens → int
-
Tokens the snapshot covers.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override