ContextResizedEvent class final
The context was recreated at a new size.
- Inheritance
-
- Object
- OrchestratorEvent
- ContextResizedEvent
Constructors
- ContextResizedEvent({required int fromTokens, required int toTokens, required ResizeReason reason})
-
Creates the event.
const
Properties
- fromTokens → int
-
The replaced context size.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- reason → ResizeReason
-
Why the resize happened.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toTokens → int
-
The new context size.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited