checkMemory method
Re-plans the context size against a fresh memory sample now, instead of waiting for the next poll tick.
Implementation
Future<void> checkMemory() => _tasks.run(_checkMemoryLocked);
Re-plans the context size against a fresh memory sample now, instead of waiting for the next poll tick.
Future<void> checkMemory() => _tasks.run(_checkMemoryLocked);