MemoryCritical class final
Even the policy's minimum context does not fit the budget.
- Inheritance
-
- Object
- PlannerDecision
- MemoryCritical
Constructors
- MemoryCritical({required int availableBytes, required int requiredBytes})
-
Creates the decision.
const
Properties
- availableBytes → int
-
Memory available when the verdict was reached.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- requiredBytes → int
-
Bytes the minimum acceptable context would need.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited