ModelLoadedEvent class final
A model finished loading (or reloading after a resize).
- Inheritance
-
- Object
- OrchestratorEvent
- ModelLoadedEvent
Constructors
- ModelLoadedEvent({required int contextTokens})
-
Creates the event.
const
Properties
- contextTokens → int
-
The context size the session was created with.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited